@@ -10,26 +10,26 @@ our $alien_key = 'gtk2_gcc';
 {
     my $VAR1;
     $Wx::dlls = $VAR1 = {
-          'adv' => 'libwx_gtk2_adv.so.3.0',
+          'base' => 'libwx_base.so.3.0',
+          'qa' => 'libwx_gtk2_qa.so.3.0',
+          'core' => 'libwx_gtk2_core.so.3.0',
+          'html' => 'libwx_gtk2_html.so.3.0',
           'net' => 'libwx_base_net.so.3.0',
           'aui' => 'libwx_gtk2_aui.so.3.0',
-          'gizmos' => 'libwx_gtk2_gizmos.so.3.0',
+          'adv' => 'libwx_gtk2_adv.so.3.0',
+          'fl' => 'libwx_gtk2_fl.so.3.0',
           'xrc' => 'libwx_gtk2_xrc.so.3.0',
-          'qa' => 'libwx_gtk2_qa.so.3.0',
-          'xml' => 'libwx_base_xml.so.3.0',
+          'gl' => 'libwx_gtk2_gl.so.3.0',
           'media' => 'libwx_gtk2_media.so.3.0',
           'stc' => 'libwx_gtk2_stc.so.3.0',
-          'fl' => 'libwx_gtk2_fl.so.3.0',
           'richtext' => 'libwx_gtk2_richtext.so.3.0',
-          'base' => 'libwx_base.so.3.0',
-          'html' => 'libwx_gtk2_html.so.3.0',
-          'gl' => 'libwx_gtk2_gl.so.3.0',
-          'core' => 'libwx_gtk2_core.so.3.0'
+          'xml' => 'libwx_base_xml.so.3.0',
+          'gizmos' => 'libwx_gtk2_gizmos.so.3.0'
         };
 ;
 }
 
-$VERSION = '0.9928'; # bootstrap will catch wrong versions
+$VERSION = '0.9932'; # bootstrap will catch wrong versions
 $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -89,6 +89,11 @@ sub _alien_path {
       last;
     }
   }
+  
+  if( $wx_path && $^O =~ /mswin/i ) {
+     require Win32;
+     $wx_path = Win32::GetShortPathName( $wx_path );
+  }
 }
 
 _alien_path();
